Various Helper Modules
######################

- **date**, **datetime**, **time** - date/datetime/time manipulation helpers.
- **decor** - helper decorators.
- **file** - file manipulation helpers.
- **formatting** - string formatting.
- **log** - helpers with stdout, stderr management, logging setup.
- **parsing** - parse arbitrary data using various helpers.
- **path** - functions for paths manipulation.
- **patterns** - design pattern helper classes for better re-usability.
- **sorting** - sorting helpers.
- **version** - manage version validation and bumping.
- **xcollections** - functions for collections.
- **xdata** - data manipulation helpers.
- **xiter** - iteration helpers.
- **xtyping** - type checking.

Source code in:

* `github <https://github.com/focusate/footil/>`_.
* `pypi <https://pypi.org/project/footil/>`_.

Contributors
============

* Silvija Butko (Focusate)
* Andrius Laukavičius (Focusate)
